# cmlidar

A package that contains colormaps for commonly used atmospheric lidar parameters:
- color ratio
- depolarization ratio 
- backscatter

## Color ratio colormaps
- *colorratio-discrete*: A discrete colormap
- *colorratio*: A sequential perceptually uniform continuous colormap 

## Depolarization ratio colormaps
- *depolarization-discrete*: A discrete colormap
- *depolarization*: A sequential perceptually uniform continuous colormap

## Backscatter
- *backscatter-discrete*: A discrete colormap
- *backscatter*: A sequential perceptually uniform continuous colormap
- *backscatter-continuous*: A continuous version of the discrete colormap keeping the contrast variations of the discrete colormap
